<a href="https://pypi.org/project/esbmtk/">
<img alt="Documentation Status" src="https://img.shields.io/pypi/v/esbmtk.svg"/>
</a>

<a href="https://pyscaffold.org">
<img alt="Project generated with PyScaffold" src="https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold"/>
</a>

<a href="https://esbmtk.readthedocs.io/en/latest/?badge=latest">
<img alt="Documentation Status" src="https://readthedocs.org/projects/esbmtk/badge/?version=latest" />
</a>


# ESBMTK - The  Earth Sciences Box Modeling Toolkit

<img src="https://raw.githubusercontent.com/uliw/esbmtk/staging/mpc.png" width="600px" align="center">"

ESBMTK is a python library that aims to simplify typical box modeling projects in the Earth-Sciences. It uses a declarative approach to describe models, and abstracts typical modeling tasks like gas-exchange and carbonate dissolution through python classes.

See the manual at <https://esbmtk.readthedocs.io/> for installation instructions, usage, and example code.

ESBMTK is available via

-   GitHub `git clone https://github.com/uliw/esbmtk.git`
-   pypi <https://pypi.org/project/esbmtk/>
-   conda-forge <https://anaconda.org/conda-forge/esbmtk>
-   sample code is available at <https://github.com/uliw/ESBMTK-Examples>

ESBMTK is under active development, before updating, please check the [Changelog](https://esbmtk.readthedocs.io/en/latest/changelog.html)